=======================
PWBS Code Documentation
=======================

******************
Basic Informations
******************

Documentation Version: v.0.4.0-dev0+documentation-1

Documented PWBS Repository Version: v.0.4.0-dev0

Documented PWBS PyPi Release: <NOT PUBLISHED> [TO BE PUBLISHED as v.0.4.0-dev1]

************************
Documentation Convention
************************

Convention of this documentation::

    # Every function and module have own RST file in DOCUMENTATION_ROOT/code_docs/ folder

***************************
Code Documentation: Modules
***************************

.. toctree::
   :maxdepth: 10
   :caption: Contents:
   :glob:

   code_docs/modules/*

******************************
Code Documentation: Submodules
******************************

.. toctree::
   :maxdepth: 10
   :caption: Contents:
   :glob:

   code_docs/submodules/*
